@@ -30,7 +30,7 @@ sub new {
 }
 
 
-sub __parse_file_Text_CSV { # 0
+sub __parse_file_Text_CSV {
     my ( $sf, $sql, $fh ) = @_;
     delete $sf->{d}{sheet_name};
     my $waiting = 'Parsing file ... ';
@@ -69,7 +69,7 @@ sub __parse_file_Text_CSV { # 0
 }
 
 
-sub __parse_file_split { # 1
+sub __parse_file_split {
     my ( $sf, $sql, $fh ) = @_;
     delete $sf->{d}{sheet_name};
     my $waiting = 'Parsing file ... ';
@@ -98,74 +98,6 @@ sub __parse_file_split { # 1
 }
 
 
-sub __parse_file_Spreadsheet_Read { # 2
-    my ( $sf, $sql, $file_ec, $book ) = @_;
-    my $tc = Term::Choose->new( $sf->{i}{tc_default} );
-    delete $sf->{d}{sheet_name};
-    my $waiting = 'Parsing file ... ';
-    my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-    $ax->print_sql( $sql, $waiting );
-    require Spreadsheet::Read;
-    if ( ! defined $book ) {
-        $book = Spreadsheet::Read::ReadData( $file_ec, cells => 0, attr => 0, rc => 1, strip => 0 );
-        if ( ! defined $book ) {
-            $tc->choose(
-                [ 'Press ENTER' ],
-                { prompt => 'No Book in ' . decode( 'locale_fs', $file_ec ) . '!' }
-            );
-            return;
-        }
-    }
-    my $sheet_count = @$book - 1; # first sheet in $book contains meta info
-    if ( $sheet_count == 0 ) {
-        $tc->choose(
-            [ 'Press ENTER' ],
-            { prompt => 'No Sheets in ' . decode( 'locale_fs', $file_ec ) . '!' }
-        );
-        return;
-    }
-    my $sheet_idx;
-    if ( $sheet_count == 1 ) {
-        $sheet_idx = 1;
-    }
-    else {
-        my @sheets = map { '- ' . ( length $book->[$_]{label} ? $book->[$_]{label} : 'sheet_' . $_ ) } 1 .. $#$book;
-        my @pre = ( undef );
-        my $choices = [ @pre, @sheets ];
-        # Choose
-        $sheet_idx = $tc->choose(
-            $choices,
-            { %{$sf->{i}{lyt_v}}, prompt => 'Choose a sheet', index => 1, default => $sf->{i}{old_sheet_idx},
-              undef => '  <=' }
-        );
-        if ( ! defined $sheet_idx || ! defined $choices->[$sheet_idx] ) {
-            return;
-        }
-        if ( $sf->{o}{G}{menu_memory} ) {
-            if ( $sf->{i}{old_sheet_idx} == $sheet_idx && ! $ENV{TC_RESET_AUTO_UP} ) {
-                $sf->{i}{old_sheet_idx} = 0;
-                return $book, $sheet_count;
-            }
-            $sf->{i}{old_sheet_idx} = $sheet_idx;
-        }
-        $sheet_idx = $sheet_idx - @pre + 1;
-    }
-    if ( $book->[$sheet_idx]{maxrow} == 0 ) {
-        my $sheet = length $book->[$sheet_idx]{label} ? $book->[$sheet_idx]{label} : 'sheet_' . $_;
-        $tc->choose(
-            [ 'Press ENTER' ],
-            { prompt => $sheet . ': empty sheet!' }
-        );
-        return $book, $sheet_count;
-    }
-    $sql->{insert_into_args} = [ Spreadsheet::Read::rows( $book->[$sheet_idx] ) ];
-    if ( ! -T $file_ec && length $book->[$sheet_idx]{label} ) {
-        $sf->{d}{sheet_name} = $book->[$sheet_idx]{label};
-    }
-    return $book, $sheet_count;
-}
-
-
 sub __parse_file_template {
     my ( $sf, $sql, $fh  ) = @_;
     delete $sf->{d}{sheet_name};
@@ -269,6 +201,73 @@ sub __parse_file_template {
 }
 
 
+sub __parse_file_Spreadsheet_Read {
+    my ( $sf, $sql, $file_ec, $book ) = @_;
+    my $tc = Term::Choose->new( $sf->{i}{tc_default} );
+    delete $sf->{d}{sheet_name};
+    my $waiting = 'Parsing file ... ';
+    my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
+    $ax->print_sql( $sql, $waiting );
+    require Spreadsheet::Read;
+    if ( ! defined $book ) {
+        $book = Spreadsheet::Read::ReadData( $file_ec, cells => 0, attr => 0, rc => 1, strip => 0 );
+        if ( ! defined $book ) {
+            $tc->choose(
+                [ 'Press ENTER' ],
+                { prompt => 'No Book in ' . decode( 'locale_fs', $file_ec ) . '!' }
+            );
+            return;
+        }
+    }
+    my $sheet_count = @$book - 1; # first sheet in $book contains meta info
+    if ( $sheet_count == 0 ) {
+        $tc->choose(
+            [ 'Press ENTER' ],
+            { prompt => 'No Sheets in ' . decode( 'locale_fs', $file_ec ) . '!' }
+        );
+        return;
+    }
+    my $sheet_idx;
+    if ( $sheet_count == 1 ) {
+        $sheet_idx = 1;
+    }
+    else {
+        my @sheets = map { '- ' . ( length $book->[$_]{label} ? $book->[$_]{label} : 'sheet_' . $_ ) } 1 .. $#$book;
+        my @pre = ( undef );
+        my $choices = [ @pre, @sheets ];
+        # Choose
+        $sheet_idx = $tc->choose(
+            $choices,
+            { %{$sf->{i}{lyt_v}}, prompt => 'Choose a sheet', index => 1, default => $sf->{i}{old_sheet_idx},
+              undef => '  <=' }
+        );
+        if ( ! defined $sheet_idx || ! defined $choices->[$sheet_idx] ) {
+            return;
+        }
+        if ( $sf->{o}{G}{menu_memory} ) {
+            if ( $sf->{i}{old_sheet_idx} == $sheet_idx && ! $ENV{TC_RESET_AUTO_UP} ) {
+                $sf->{i}{old_sheet_idx} = 0;
+                return $book, $sheet_count;
+            }
+            $sf->{i}{old_sheet_idx} = $sheet_idx;
+        }
+        $sheet_idx = $sheet_idx - @pre + 1;
+    }
+    if ( $book->[$sheet_idx]{maxrow} == 0 ) {
+        my $sheet = length $book->[$sheet_idx]{label} ? $book->[$sheet_idx]{label} : 'sheet_' . $_;
+        $tc->choose(
+            [ 'Press ENTER' ],
+            { prompt => $sheet . ': empty sheet!' }
+        );
+        return $book, $sheet_count;
+    }
+    $sql->{insert_into_args} = [ Spreadsheet::Read::rows( $book->[$sheet_idx] ) ];
+    if ( ! -T $file_ec && length $book->[$sheet_idx]{label} ) {
+        $sf->{d}{sheet_name} = $book->[$sheet_idx]{label};
+    }
+    return $book, $sheet_count;
+}
+
 
 
 1;
